@@ -17,6 +17,11 @@ from openstack import resource2
 
 
 class Message(resource2.Resource):
+    # FIXME(anyone): The name string of `location` field of Zaqar API response
+    # is lower case. That is inconsistent with the guide from API-WG. This is
+    # a workaround for this issue.
+    location = resource2.Header("location")
+
     resources_key = 'messages'
     base_path = '/queues/%(queue_name)s/messages'
     service = message_service.MessageService()
@@ -126,6 +131,11 @@ class Message(resource2.Resource):
         }
 
         request.headers.update(headers)
+        # For Zaqar v2 API requires client to specify claim_id as query
+        # parameter when deleting a message that has been claimed, we
+        # rebuild the request URI if claim_id is not None.
+        if self.claim_id:
+            request.uri += '?claim_id=%s' % self.claim_id
         response = session.delete(request.uri, endpoint_filter=self.service,
                                   headers=headers)
 
