@@ -15,6 +15,9 @@ from openstack.orchestration.v1 import resource as _resource
 from openstack.orchestration.v1 import software_config as _sc
 from openstack.orchestration.v1 import software_deployment as _sd
 from openstack.orchestration.v1 import stack as _stack
+from openstack.orchestration.v1 import stack_environment as _stack_environment
+from openstack.orchestration.v1 import stack_files as _stack_files
+from openstack.orchestration.v1 import stack_template as _stack_template
 from openstack.orchestration.v1 import template as _template
 from openstack import proxy2
 
@@ -107,6 +110,82 @@ class Proxy(proxy2.BaseProxy):
         """
         self._delete(_stack.Stack, stack, ignore_missing=ignore_missing)
 
+    def check_stack(self, stack):
+        """Check a stack's status
+
+        Since this is an asynchronous action, the only way to check the result
+        is to track the stack's status.
+
+        :param stack: The value can be either the ID of a stack or an instance
+                      of :class:`~openstack.orchestration.v1.stack.Stack`.
+        :returns: ``None``
+        """
+        if isinstance(stack, _stack.Stack):
+            stk_obj = stack
+        else:
+            stk_obj = _stack.Stack.existing(id=stack)
+
+        stk_obj.check(self._session)
+
+    def get_stack_template(self, stack):
+        """Get template used by a stack
+
+        :param stack: The value can be the ID of a stack or an instance of
+            :class:`~openstack.orchestration.v1.stack.Stack`
+
+        :returns: One object of
+            :class:`~openstack.orchestration.v1.stack_template.StackTemplate`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        if isinstance(stack, _stack.Stack):
+            obj = stack
+        else:
+            obj = self._find(_stack.Stack, stack, ignore_missing=False)
+
+        return self._get(_stack_template.StackTemplate, requires_id=False,
+                         stack_name=obj.name, stack_id=obj.id)
+
+    def get_stack_environment(self, stack):
+        """Get environment used by a stack
+
+        :param stack: The value can be the ID of a stack or an instance of
+            :class:`~openstack.orchestration.v1.stack.Stack`
+
+        :returns: One object of
+                  :class:`~openstack.orchestration.v1.stack_environment.\
+                  StackEnvironment`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+                 resource can be found.
+        """
+        if isinstance(stack, _stack.Stack):
+            obj = stack
+        else:
+            obj = self._find(_stack.Stack, stack, ignore_missing=False)
+
+        return self._get(_stack_environment.StackEnvironment,
+                         requires_id=False, stack_name=obj.name,
+                         stack_id=obj.id)
+
+    def get_stack_files(self, stack):
+        """Get files used by a stack
+
+        :param stack: The value can be the ID of a stack or an instance of
+            :class:`~openstack.orchestration.v1.stack.Stack`
+
+        :returns: A dictionary containing the names and contents of all files
+                  used by the stack.
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when the stack cannot be found.
+        """
+        if isinstance(stack, _stack.Stack):
+            stk = stack
+        else:
+            stk = self._find(_stack.Stack, stack, ignore_missing=False)
+
+        obj = _stack_files.StackFiles(stack_name=stk.name, stack_id=stk.id)
+        return obj.get(self._session)
+
     def resources(self, stack, **query):
         """Return a generator of resources
 
@@ -151,8 +230,8 @@ class Proxy(proxy2.BaseProxy):
         :param dict query: Optional query parameters to be sent to limit the
                            software configs returned.
         :returns: A generator of software config objects.
-        :rtype:
-        :class:`~openstack.orchestration.v1.software_config.SoftwareConfig`
+        :rtype: :class:`~openstack.orchestration.v1.software_config.\
+                SoftwareConfig`
         """
         return self._list(_sc.SoftwareConfig, paginated=True, **query)
 
@@ -203,8 +282,8 @@ class Proxy(proxy2.BaseProxy):
         :param dict query: Optional query parameters to be sent to limit the
                            software deployments returned.
         :returns: A generator of software deployment objects.
-        :rtype:
-        :class:`~openstack.orchestration.v1.software_deployment.SoftwareDeployment`
+        :rtype: :class:`~openstack.orchestration.v1.software_deployment.\
+                SoftwareDeployment`
         """
         return self._list(_sd.SoftwareDeployment, paginated=False, **query)
 
@@ -246,8 +325,8 @@ class Proxy(proxy2.BaseProxy):
                            represented by ``software_deployment``.
 
         :returns: The updated software deployment
-        :rtype:
-        :class:`~openstack.orchestration.v1.software_deployment.SoftwareDeployment`
+        :rtype: :class:`~openstack.orchestration.v1.software_deployment.\
+                SoftwareDeployment`
         """
         return self._update(_sd.SoftwareDeployment, software_deployment,
                             **attrs)
@@ -278,6 +357,6 @@ class Proxy(proxy2.BaseProxy):
                 "'template_url' must be specified when template is None")
 
         tmpl = _template.Template.new()
-        return tmpl.validate(self.session, template, environment=environment,
+        return tmpl.validate(self._session, template, environment=environment,
                              template_url=template_url,
                              ignore_errors=ignore_errors)
