@@ -424,6 +424,19 @@ class TestServer(testtools.TestCase):
         self.sess.post.assert_called_with(
             url, endpoint_filter=sot.service, json=body, headers=headers)
 
+    def test_backup(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.backup(self.sess, "name", "daily", 1)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {"createBackup": {"name": "name", "backup_type": "daily",
+                                 "rotation": 1}}
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, endpoint_filter=sot.service, json=body, headers=headers)
+
     def test_pause(self):
         sot = server.Server(**EXAMPLE)
 
@@ -606,3 +619,57 @@ class TestServer(testtools.TestCase):
         headers = {'Accept': ''}
         self.sess.post.assert_called_with(
             url, endpoint_filter=sot.service, json=body, headers=headers)
+
+    def test_migrate(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.migrate(self.sess)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {"migrate": None}
+
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, endpoint_filter=sot.service, json=body, headers=headers)
+
+    def test_get_console_output(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.get_console_output(self.sess)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {'os-getConsoleOutput': {}}
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, endpoint_filter=sot.service, json=body, headers=headers)
+
+        res = sot.get_console_output(self.sess, length=1)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {'os-getConsoleOutput': {'length': 1}}
+
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, endpoint_filter=sot.service, json=body, headers=headers)
+
+    def test_live_migrate(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.live_migrate(self.sess, host='HOST2', force=False)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {
+            "os-migrateLive": {
+                "host": 'HOST2',
+                "block_migration": "auto",
+                "force": False
+            }
+        }
+
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, endpoint_filter=sot.service, json=body, headers=headers)
