@@ -16,7 +16,6 @@ from openstack.identity.v3 import role
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
-    'domain_id': '1',
     'id': IDENTIFIER,
     'links': {'self': 'http://example.com/user1'},
     'name': '2',
@@ -36,11 +35,9 @@ class TestRole(testtools.TestCase):
         self.assertTrue(sot.allow_update)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
-        self.assertTrue(sot.put_create)
 
     def test_make_it(self):
         sot = role.Role(**EXAMPLE)
-        self.assertEqual(EXAMPLE['domain_id'], sot.domain_id)
         self.assertEqual(EXAMPLE['id'], sot.id)
         self.assertEqual(EXAMPLE['links'], sot.links)
         self.assertEqual(EXAMPLE['name'], sot.name)
