@@ -29,7 +29,8 @@ EXAMPLE = {
     'host': 'test-host',
     'id': IDENTIFIER,
     'started_at': '2016-07-09T12:14:57.233772',
-    'topic': 'test-topic'
+    'topic': 'test-topic',
+    'ha_state': 'active'
 }
 
 
@@ -63,6 +64,7 @@ class TestAgent(testtools.TestCase):
         self.assertEqual(EXAMPLE['id'], sot.id)
         self.assertEqual(EXAMPLE['started_at'], sot.started_at)
         self.assertEqual(EXAMPLE['topic'], sot.topic)
+        self.assertEqual(EXAMPLE['ha_state'], sot.ha_state)
 
     def test_add_agent_to_network(self):
         # Add agent to network
@@ -83,24 +85,68 @@ class TestAgent(testtools.TestCase):
         # Remove agent from agent
         net = agent.Agent(**EXAMPLE)
         sess = mock.Mock()
-        self.assertIsNone(net.remove_agent_from_network(sess))
-        body = {}
+        network_id = {}
+        self.assertIsNone(net.remove_agent_from_network(sess, network_id))
+        body = {'network_id': {}}
 
         sess.delete.assert_called_with('agents/IDENTIFIER/dhcp-networks/',
                                        endpoint_filter=net.service, json=body)
 
+    def test_add_router_to_agent(self):
+        # Add router to agent
+        sot = agent.Agent(**EXAMPLE)
+        response = mock.Mock()
+        response.body = {'router_id': '1'}
+        response.json = mock.Mock(return_value=response.body)
+        sess = mock.Mock()
+        sess.post = mock.Mock(return_value=response)
+        router_id = '1'
+        self.assertEqual(response.body,
+                         sot.add_router_to_agent(sess, router_id))
+        body = {'router_id': router_id}
+        url = 'agents/IDENTIFIER/l3-routers'
+        sess.post.assert_called_with(url, endpoint_filter=sot.service,
+                                     json=body)
 
-class TestDHCPAgentHostingNetwork(testtools.TestCase):
+    def test_remove_router_from_agent(self):
+        # Remove router from agent
+        sot = agent.Agent(**EXAMPLE)
+        sess = mock.Mock()
+        router_id = {}
+        self.assertIsNone(sot.remove_router_from_agent(sess, router_id))
+        body = {'router_id': {}}
+
+        sess.delete.assert_called_with('agents/IDENTIFIER/l3-routers/',
+                                       endpoint_filter=sot.service, json=body)
+
+
+class TestNetworkHostingDHCPAgent(testtools.TestCase):
 
     def test_basic(self):
-        net = agent.DHCPAgentHostingNetwork()
-        self.assertEqual('network', net.resource_key)
-        self.assertEqual('networks', net.resources_key)
-        self.assertEqual('/agents/%(agent_id)s/dhcp-networks', net.base_path)
-        self.assertEqual('dhcp-network', net.resource_name)
+        net = agent.NetworkHostingDHCPAgent()
+        self.assertEqual('agent', net.resource_key)
+        self.assertEqual('agents', net.resources_key)
+        self.assertEqual('/networks/%(network_id)s/dhcp-agents', net.base_path)
+        self.assertEqual('dhcp-agent', net.resource_name)
         self.assertEqual('network', net.service.service_type)
         self.assertFalse(net.allow_create)
         self.assertTrue(net.allow_get)
         self.assertFalse(net.allow_update)
         self.assertFalse(net.allow_delete)
         self.assertTrue(net.allow_list)
+
+
+class TestRouterL3Agent(testtools.TestCase):
+
+    def test_basic(self):
+        sot = agent.RouterL3Agent()
+        self.assertEqual('agent', sot.resource_key)
+        self.assertEqual('agents', sot.resources_key)
+        self.assertEqual('/routers/%(router_id)s/l3-agents', sot.base_path)
+        self.assertEqual('l3-agent', sot.resource_name)
+        self.assertEqual('network', sot.service.service_type)
+        self.assertFalse(sot.allow_create)
+        self.assertTrue(sot.allow_retrieve)
+        self.assertFalse(sot.allow_update)
+        self.assertFalse(sot.allow_delete)
+        self.assertTrue(sot.allow_list)
